.. role:: pythoncode(code)
   :language: python

.. _boario-quickstart:

Tutorials
============

For the following examples, we assume you have followed installation instructions.

If you encounter any problems or question with one of the tutorials or examples below, please `raise an issue`_ on the repository, or `contact the developer`_.

.. _raise an issue: https://github.com/spjuhel/BoARIO/issues/new

.. _contact the developer: pro@sjuhel.org

.. toctree::
   :maxdepth: 1

   notebooks/boario-quickstart
   tutorials/model-type
   tutorials/model-params
   tutorials/mriot-input
   tutorials/simulation-context
   tutorials/boario-events
   tutorials/monetary-factors
